@@ -21,8 +21,10 @@ _ = gettext.gettext
 
 
 def date_parse(text, format_='%x'):
-    dayfirst = datetime.date(1988, 8, 16).strftime(format_).index('16') == 0
-    yearfirst = datetime.date(1988, 8, 16).strftime(format_).index('88') <= 2
+    formatted_date = datetime.date(1988, 7, 16).strftime(format_)
+    dayfirst = formatted_date.index('16') == 0
+    monthfirst = formatted_date.index('7') <= 1
+    yearfirst = not dayfirst and not monthfirst
     return parse(text, dayfirst=dayfirst, yearfirst=yearfirst, ignoretz=True)
 
 
@@ -456,20 +458,10 @@ gobject.type_register(DateTime)
 
 
 def popup_position(widget, popup):
-
-    req_width, req_height = popup.size_request()
+    # XXX It does not result in the same position in GTK2 and GTK3
     x, y = widget.window.get_origin()
     allocation = widget.get_allocation()
-    width = allocation.width
-    height = allocation.height
-
-    x += width - req_width
-    y += height
-
-    x = max(x, 0)
-    y = max(y, 0)
-
-    popup.move(x, y)
+    popup.move(x + allocation.x, y + allocation.y + allocation.height)
 
 
 def popup_show(popup):
