@@ -20,6 +20,7 @@ from tryton.common.completion import get_completion, update_completion
 from tryton.common.datetime_ import Date, DateTime
 from tryton.common.domain_parser import quote
 from tryton.common.entry_position import reset_position
+from tryton.common.widget_style import set_widget_style
 
 _ = gettext.gettext
 
@@ -53,6 +54,7 @@ class DictEntry(object):
 
     def set_readonly(self, readonly):
         self.widget.set_editable(not readonly)
+        set_widget_style(self.widget, not readonly)
 
 
 class DictBooleanEntry(DictEntry):
